==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_YOURNAME","sminiz");
define("_SORTASC","Yukar Doru Srala");
define("_SORTDESC","Aa Dou Srala");
define("_CANCEL","ptal");
define("_YES","Evet");
define("_NO","Hayr");
define("_SCORE","Skor:");
define("_REPLYMAIN","Yorum Ekle");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_WRITEREVIEW","zlenim Yaz");
define("_WRITEREVIEWFOR","zlenim Yaz:");
define("_ENTERINFO","Ltfen tanmlara bal bilgilerini girin");
define("_PRODUCTTITLE","rn Ad");
define("_NAMEPRODUCT","zlenimi yaplan rnn ad.");
define("_REVIEW","zlenim");
define("_CHECKREVIEW","Tam izleniminiz. Ltfen dil bilgisini dzgn kullann! En az 100 kelime kullanmaya aln. Biliyorsanz HTML tag'leri kullanabilirsiniz.");
define("_FULLNAMEREQ","Tam Adnz. Gerekli.");
define("_REMAIL","Email'iniz");
define("_REMAILREQ","E-mail adresiniz. Gerekli.");
define("_SELECTSCORE","rn Puan");
define("_RELATEDLINK","lgili Balant");
define("_PRODUCTSITE","rnn resmi web sitesi. Adresin \"http://\" ile baladndan emin olun");
define("_LINKTITLE","Balant Bal");
define("_LINKTITLEREQ","lgili balantnz varsa gerekli.");
define("_RIMAGEFILE","Resim Dosyas Ad");
define("_RIMAGEFILEREQ","Kapak grafiinin ad, images/reviews/'de yer alr. Zorunlu deil.");
define("_CHECKINFO","Ltfen girdiiniz bilgilerin 100% doruluundan, dil bilgisi ve imlay doru kullandnzdan emin olun. Yaznn tamamn BYK HARFLER ile yazmayn.");
define("_INVALIDTITLE","Geersiz sim... Bo olamaz");
define("_INVALIDSCORE","Geersiz Puan... 1 ile 10 arasnda olmal");
define("_INVALIDTEXT","Geersiz zleim Metni... Bo olamaz");
define("_INVALIDHITS","Hit pozitif tamsay olmal");
define("_CHECKNAME","Adnz ve email adresinizi girmelisiniz");
define("_INVALIDEMAIL","Geersiz email (rn: isim@hotmail.com)");
define("_INVALIDLINK","Balant bal ve adresini BRLKTE girmeli veya bo brakmalsnz");
define("_ADDED","Eklenme");
define("_REVIEWER","Yazan:");
define("_REVIEWID","zlenim ID");
define("_HITS","Hit");
define("_LOOKSRIGHT","Doru grnyor mu?");
define("_RMODIFIED","deitirildi");
define("_RADDED","eklenecek");
define("_ADMINLOGGED","Ynetici girii yapmsnz... Bu izlenim hemen");
define("_RTHANKS","Bu izlenimi gnderdiiniz iin teekkrler");
define("_MODIFICATION","deitirme");
define("_ISAVAILABLE","zleniminiz veritabanna eklendi.");
define("_EDITORWILLLOOK","Editrler tarafndan incelendikten sonra eklenecek.");
define("_RBACK","zlenimlere Geri Dn");
define("_RWELCOME","zlenimler Blmne Hogeldiniz");
define("_10MOSTPOP","en popler 10 izlenim");
define("_10MOSTREC","en yeni 10 izlenim");
define("_THEREARE","Veritabannda");
define("_REVIEWSINDB","izlenim bulunuyor");
define("_REVIEWS","zlenimler");
define("_REVIEWSLETTER","zlenimler:");
define("_NOREVIEWS","Bu harf iin izlenim yok:");
define("_TOTALREVIEWS","izlenim bulundu.");
define("_RETURN2MAIN","Ana Menye Dn");
define("_REVIEWCOMMENT","zlenim Yorumu:");
define("_YOURNICK","Nickname'iniz:");
define("_RCREATEACCOUNT","Yeni hesap <a href=modules.php?name=Your_Account&op=new_user>yarat</a>");
define("_YOURCOMMENT","Yorumunuz:");
define("_MYSCORE","Puanm:");
define("_REVIEWMOD","zlenim Deitir");
define("_RDATE","Tarih:");
define("_RTITLE","Balk:");
define("_RTEXT","Metin:");
define("_REVEMAIL","Email:");
define("_RLINK","Balant:");
define("_RLINKTITLE","Balant Bal:");
define("_COVERIMAGE","Kapak Grafii:");
define("_PREMODS","Deiiklik nizle");
define("_PAGE","Sayfa");
define("_PAGEBREAK","Birden fazla sayfa kullanmak iin kesmek istediiniz yere <b>&lt;!--pagebreak--&gt;</b> yazabilirsiniz.");
define("_PREVIEW","nizleme");
define("_LANGUAGE","Dil");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","nceki Sayfa");
define("_NEXT","Sonraki Sayfa");
define("_YOURNAME","sminiz");
define("_SORTASC","Yukar Doru Srala");
define("_SORTDESC","Aa Dou Srala");
define("_CANCEL","ptal");
define("_YES","Evet");
define("_NO","Hayr");
define("_SCORE","Skor:");
define("_REPLYMAIN","Yorum Ekle");
define("_ALLOWEDHTML","zin Verilen HTML:");
define("_POSTANON","Anonim Olarak Gnder");
define("_WRITEREVIEW","zlenim Yaz");
define("_WRITEREVIEWFOR","zlenim Yaz:");
define("_ENTERINFO","Ltfen tanmlara bal bilgilerini girin");
define("_PRODUCTTITLE","rn Ad");
define("_NAMEPRODUCT","zlenimi yaplan rnn ad.");
define("_REVIEW","zlenim");
define("_CHECKREVIEW","Tam izleniminiz. Ltfen dil bilgisini dzgn kullann! En az 100 kelime kullanmaya aln. Biliyorsanz HTML tag'leri kullanabilirsiniz.");
define("_FULLNAMEREQ","Tam Adnz. Gerekli.");
define("_REMAIL","Email'iniz");
define("_REMAILREQ","E-mail adresiniz. Gerekli.");
define("_SELECTSCORE","rn Puan");
define("_RELATEDLINK","lgili Balant");
define("_PRODUCTSITE","rnn resmi web sitesi. Adresin \"http://\" ile baladndan emin olun");
define("_LINKTITLE","Balant Bal");
define("_LINKTITLEREQ","lgili balantnz varsa gerekli.");
define("_RIMAGEFILE","Resim Dosyas Ad");
define("_RIMAGEFILEREQ","Kapak grafiinin ad, images/reviews/'de yer alr. Zorunlu deil.");
define("_CHECKINFO","Ltfen girdiiniz bilgilerin 100% doruluundan, dil bilgisi ve imlay doru kullandnzdan emin olun. Yaznn tamamn BYK HARFLER ile yazmayn.");
define("_INVALIDTITLE","Geersiz sim... Bo olamaz");
define("_INVALIDSCORE","Geersiz Puan... 1 ile 10 arasnda olmal");
define("_INVALIDTEXT","Geersiz zleim Metni... Bo olamaz");
define("_INVALIDHITS","Hit pozitif tamsay olmal");
define("_CHECKNAME","Adnz ve email adresinizi girmelisiniz");
define("_INVALIDEMAIL","Geersiz email (rn: isim@hotmail.com)");
define("_INVALIDLINK","Balant bal ve adresini BRLKTE girmeli veya bo brakmalsnz");
define("_ADDED","Eklenme");
define("_REVIEWER","Yazan:");
define("_REVIEWID","zlenim ID");
define("_HITS","Hit");
define("_LOOKSRIGHT","Doru grnyor mu?");
define("_RMODIFIED","deitirildi");
define("_RADDED","eklenecek");
define("_ADMINLOGGED","Ynetici girii yapmsnz... Bu izlenim hemen");
define("_RTHANKS","Bu izlenimi gnderdiiniz iin teekkrler");
define("_MODIFICATION","deitirme");
define("_ISAVAILABLE","zleniminiz veritabanna eklendi.");
define("_EDITORWILLLOOK","Editrler tarafndan incelendikten sonra eklenecek.");
define("_RBACK","zlenimlere Geri Dn");
define("_RWELCOME","zlenimler Blmne Hogeldiniz");
define("_10MOSTPOP","en popler 10 izlenim");
define("_10MOSTREC","en yeni 10 izlenim");
define("_THEREARE","Veritabannda");
define("_REVIEWSINDB","izlenim bulunuyor");
define("_REVIEWS","zlenimler");
define("_REVIEWSLETTER","zlenimler:");
define("_NOREVIEWS","Bu harf iin izlenim yok:");
define("_TOTALREVIEWS","izlenim bulundu.");
define("_RETURN2MAIN","Ana Menye Dn");
define("_REVIEWCOMMENT","zlenim Yorumu:");
define("_YOURNICK","Nickname'iniz:");
define("_RCREATEACCOUNT","Yeni hesap <a href=modules.php?name=Your_Account&op=new_user>yarat</a>");
define("_YOURCOMMENT","Yorumunuz:");
define("_MYSCORE","Puanm:");
define("_REVIEWMOD","zlenim Deitir");
define("_RDATE","Tarih:");
define("_RTITLE","Balk:");
define("_RTEXT","Metin:");
define("_REVEMAIL","Email:");
define("_RLINK","Balant:");
define("_RLINKTITLE","Balant Bal:");
define("_COVERIMAGE","Kapak Grafii:");
define("_PREMODS","Deiiklik nizle");
define("_PAGE","Sayfa");
define("_PAGEBREAK","Birden fazla sayfa kullanmak iin kesmek istediiniz yere <b>&lt;!--pagebreak--&gt;</b> yazabilirsiniz.");
define("_PREVIEW","nizleme");
define("_LANGUAGE","Dil");

?>
